@@ -1,11 +1,11 @@
 /* Main program for the toy PPL/SICStus-Prolog CLP(Q) interpreter.
-   Copyright (C) 2001-2008 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2001-2006 Roberto Bagnara <bagnara@cs.unipr.it>
 
 This file is part of the Parma Polyhedra Library (PPL).
 
 The PPL is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 3 of the License, or (at your
+Free Software Foundation; either version 2 of the License, or (at your
 option) any later version.
 
 The PPL is distributed in the hope that it will be useful, but WITHOUT
@@ -20,24 +20,16 @@ Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 For the most up-to-date information see the Parma Polyhedra Library
 site: http://www.cs.unipr.it/ppl/ . */
 
-:- ensure_loaded('ppl_sicstus.pl').
+:- set_prolog_flag(language, iso).
 
-version_dependent_declarations :-
-	prolog_flag(version, V),
-	atom_codes(V, VList),
-	VList = [_S, _I, _C, _S, _t, _u, _s, _, N|_],
-	(N is "4" ->
-	    true
-	;
-	    set_prolog_flag(language, iso),
-	    use_module(library(lists), [append/3, member/2])
-	).
+:- ensure_loaded('ppl_sicstus.pl').
+:- use_module(library(lists), [append/3, member/2]).
 
 eat_eol :-
 	get_code(user_input, _EOL).
 
 main(CLPQ) :-
-	version_dependent_declarations,
-	ensure_loaded(CLPQ),
-	set_prolog_flag(fileerrors, off),
-	common_main.
+    ensure_loaded(CLPQ),
+    set_prolog_flag(language, iso),	% FIXME: this is not ISO Prolog
+    nofileerrors,			% FIXME: this is not ISO Prolog
+    common_main.
