@@ -1,11 +1,11 @@
-/* Main program for the PPL/SWI-Prolog checker.
-   Copyright (C) 2001-2010 Roberto Bagnara <bagnara@cs.unipr.it>
+/* Main program for the toy PPL/SICStus-Prolog CLP(Q) predicate checker.
+   Copyright (C) 2001-2006 Roberto Bagnara <bagnara@cs.unipr.it>
 
 This file is part of the Parma Polyhedra Library (PPL).
 
 The PPL is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 3 of the License, or (at your
+Free Software Foundation; either version 2 of the License, or (at your
 option) any later version.
 
 The PPL is distributed in the hope that it will be useful, but WITHOUT
