@@ -1,5 +1,5 @@
 /* Variable class implementation (non-inline functions).
-   Copyright (C) 2001 Roberto Bagnara <bagnara@cs.unipr.it>
+   Copyright (C) 2001-2006 Roberto Bagnara <bagnara@cs.unipr.it>
 
 This file is part of the Parma Polyhedra Library (PPL).
 
@@ -14,9 +14,8 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
-USA.
+along with this program; if not, write to the Free Software Foundation,
+Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111-1307, USA.
 
 For the most up-to-date information see the Parma Polyhedra Library
 site: http://www.cs.unipr.it/ppl/ . */
@@ -29,13 +28,25 @@ site: http://www.cs.unipr.it/ppl/ . */
 
 namespace PPL = Parma_Polyhedra_Library;
 
-std::ostream&
-PPL::operator <<(std::ostream& s, const Variable& v) {
-  unsigned int varid = v.id();
-  char c = 'A' + (varid % 26);
-  unsigned int i = varid / 26;
-  s << c;
-  if (i > 0)
+PPL::Variable::output_function_type*
+PPL::Variable::current_output_function = 0;
+
+bool
+PPL::Variable::OK() const {
+  return id() < max_space_dimension();
+}
+
+void
+PPL::Variable::default_output_function(std::ostream& s, const Variable& v) {
+  dimension_type varid = v.id();
+  s << static_cast<char>('A' + varid % 26);
+  if (dimension_type i = varid / 26)
     s << i;
+}
+
+/*! \relates Parma_Polyhedra_Library::Variable */
+std::ostream&
+PPL::IO_Operators::operator<<(std::ostream& s, const Variable& v) {
+  (*Variable::current_output_function)(s, v);
   return s;
 }
